=======
AgaveDB
=======

.. image:: https://badge.fury.io/py/agavedb.svg
    :target: http://badge.fury.io/py/agavedb

.. image:: https://travis-ci.org/TACC/agavedb.svg?branch=master
    :target: https://travis-ci.org/TACC/agavedb

.. image:: https://readthedocs.org/projects/agavedb/badge/?version=latest
    :target: https://readthedocs.org/projects/agavedb/?badge=latest

.. image:: https://img.shields.io/pypi/l/Django.svg
    :target: https://raw.githubusercontent.com/TACC/agavedb/master/LICENSE

**Multiuser-aware key/value store built using the Agave metadata API**

- Documentation: https://agavedb.readthedocs.io/en/latest/
- GitHub: https://github.com/TACC/agavedb
- PyPI: https://pypi.python.org/pypi/agavedb
- Free software: 3-Clause BSD License

Installation
============

Install from PyPI_ ::

    pip install agavedb


Install from GitHub checkout::

    cd agavedb
    python setup.py install


Tests
=====

Tests are implemented using tox_. To run them, just type ``tox``

.. _PyPI: https://pypi.python.org/pypi/agavedb
.. _tox: https://tox.readthedocs.io/en/latest

